toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  return 'AndroidParams{'
      'isCustomNotification: $isCustomNotification, '
      'isCustomSmallExNotification: $isCustomSmallExNotification, '
      'isShowLogo: $isShowLogo, '
      'logoUrl: $logoUrl, '
      'isShowCallID: $isShowCallID, '
      'ringtonePath: $ringtonePath, '
      'backgroundColor: $backgroundColor, '
      'backgroundUrl: $backgroundUrl, '
      'actionColor: $actionColor, '
      'textColor: $textColor, '
      'incomingCallNotificationChannelName: $incomingCallNotificationChannelName, '
      'missedCallNotificationChannelName: $missedCallNotificationChannelName, '
      'isShowFullLockedScreen: $isShowFullLockedScreen, '
      'isImportant: $isImportant, '
      'isBot: $isBot, '
      'isFullScreen: $isFullScreen, '
      'from: $from, '
      'textAccept: $textAccept, '
      'textDecline: $textDecline'
      '}';
}