CallEventActionCallToggleDmtf class

Inheritance

Constructors

CallEventActionCallToggleDmtf(String id, String digits, DTMFActionType type)
const

Properties

digits String
final
eventName String
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type DTMFActionType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited