CallEventActionCallToggleGroup class

Inheritance

Constructors

CallEventActionCallToggleGroup(String id, String? callUUIDToGroupWith)
const

Properties

callUUIDToGroupWith String?
final
eventName String
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited