CallEventConstants class abstract
Event name constants for external reference
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- actionCallAccept → const String
- actionCallCallback → const String
- actionCallConnected → const String
- actionCallCustom → const String
- actionCallDecline → const String
- actionCallEnded → const String
- actionCallIncoming → const String
- actionCallStart → const String
- actionCallTimeout → const String
- actionCallToggleAudioSession → const String
- actionCallToggleDmtf → const String
- actionCallToggleGroup → const String
- actionCallToggleHold → const String
- actionCallToggleMute → const String
- actionDidUpdateDevicePushTokenVoip → const String