toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  return 'CallKitParams{'
      'id: $id, '
      'nameCaller: $nameCaller, '
      'appName: $appName, '
      'avatar: $avatar, '
      'handle: $handle, '
      'type: $type, '
      'duration: $duration, '
      'isAccepted: $isAccepted, '
      'missedCallNotification: $missedCallNotification, '
      'callingNotification: $callingNotification, '
      'extra: $extra, '
      'headers: $headers, '
      'android: $android, '
      'ios: $ios'
      '}';
}